<?php

namespace Drupal\cloudflare_stream\Service;

/**
 * Interface CloudflareStreamInterface.
 *
 * Describes the Cloudflare Stream service functions.
 */
interface CloudflareStreamInterface {

  /**
   * Whether or not the debug is enabled.
   *
   * @return bool
   *   True if a debug is enabled, false otherwise.
   */
  public function debugEnabled();

  /**
   * Return the email from Cloudflare Stream configuration.
   *
   * @return string
   *   The email.
   */
  public function getEmail();

  /**
   * Returns the api_key from Cloudflare Stream configuration.
   *
   * @return string
   *   The API key.
   */
  public function getApiKey();

  /**
   * Returns the zone ID from Cloudflare Stream configuration.
   *
   * @return string
   *   The zone ID.
   */
  public function getZoneId();

  /**
   * Returns the account ID from Cloudflare Stream configuration.
   *
   * @return string
   *   The account ID.
   */
  public function getAccountId();

  /**
   * Whether or not to replace the source files.
   *
   * @return bool
   *   True if source files needs to be replaced, false otherwise.
   */
  public function replaceSourceFiles();

  /**
   * Lists all allowed file extensions.
   *
   * @return string
   *   The allowed file extensions.
   */
  public function listAllowedFileExtensions();

}
